# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .fraud_list_rules_params import FraudListRulesParams as FraudListRulesParams
